diff -u clutter-1.0-1.0.8/debian/rules clutter-1.0-1.0.8/debian/rules
--- clutter-1.0-1.0.8/debian/rules
+++ clutter-1.0-1.0.8/debian/rules
@@ -9,10 +9,6 @@
 DEB_COMPRESS_EXCLUDE += .c
 DEB_CONFIGURE_EXTRA_FLAGS += --enable-gtk-doc --enable-introspection=yes
 
-CPU := $(shell dpkg-architecture -qDEB_HOST_ARCH_CPU)
-ifeq ($(CPU),arm)
-CFLAGS += -march=armv5t
-endif
 
 $(patsubst %,binary-predeb/%,$(DEB_ALL_PACKAGES)) ::
 	dh_girepository -p$(cdbs_curpkg)
diff -u clutter-1.0-1.0.8/debian/changelog clutter-1.0-1.0.8/debian/changelog
--- clutter-1.0-1.0.8/debian/changelog
+++ clutter-1.0-1.0.8/debian/changelog
@@ -1,3 +1,16 @@
+clutter-1.0 (1.0.8-1.1) unstable; urgency=low
+
+  [ gregor herrmann ]
+  * Non-maintainer upload.
+
+  [ Heiko Stuebner ]
+  * 0001-disable-armv5t-specific-optimization.patch:
+    Fix armv4t compatiblity (Closes: #580106)
+  * 0002-fix-spelling-errors.patch:
+    Fix spelling errors causing a failing build (Closes: #583465)
+
+ -- gregor herrmann <gregoa@debian.org>  Fri, 02 Jul 2010 01:01:58 +0200
+
 clutter-1.0 (1.0.8-1) unstable; urgency=low
 
   * New upstream release
only in patch2:
unchanged:
--- clutter-1.0-1.0.8.orig/debian/patches/0001-disable-armv5t-specific-optimization.patch
+++ clutter-1.0-1.0.8/debian/patches/0001-disable-armv5t-specific-optimization.patch
@@ -0,0 +1,55 @@
+From 7bed3265be9d58ee11f5860dac0ca6fbcd31f996 Mon Sep 17 00:00:00 2001
+From: Heiko Stuebner <heiko@sntech.de>
+Date: Mon, 28 Jun 2010 16:23:09 +0200
+Subject: [PATCH] disable armv5t specific optimization
+
+---
+ clutter/cogl/common/cogl-fixed.c |   18 +++++++++---------
+ 1 files changed, 9 insertions(+), 9 deletions(-)
+
+diff --git a/clutter/cogl/common/cogl-fixed.c b/clutter/cogl/common/cogl-fixed.c
+index 13a9676..fee482c 100644
+--- a/clutter/cogl/common/cogl-fixed.c
++++ b/clutter/cogl/common/cogl-fixed.c
+@@ -626,21 +626,21 @@ cogl_fixed_sqrt (CoglFixed x)
+ 	/*
+ 	 * Find the highest bit set
+ 	 */
+-#if __arm__
++//#if __arm__
+ 	/* This actually requires at least arm v5, but gcc does not seem
+ 	 * to set the architecture defines correctly, and it is I think
+ 	 * very unlikely that anyone will want to use clutter on anything
+ 	 * less than v5.
+ 	 */
+-	int bit;
+-	__asm__ ("clz  %0, %1\n"
+-		 "rsb  %0, %0, #31\n"
+-		 :"=r"(bit)
+-		 :"r" (x));
++//	int bit;
++//	__asm__ ("clz  %0, %1\n"
++//		 "rsb  %0, %0, #31\n"
++//		 :"=r"(bit)
++//		 :"r" (x));
+ 
+ 	/* make even (2n) */
+-	bit &= 0xfffffffe;
+-#else
++//	bit &= 0xfffffffe;
++//#else
+ 	/* TODO -- add i386 branch using bshr
+ 	 *
+ 	 * NB: it's been said that the bshr instruction is poorly implemented
+@@ -656,7 +656,7 @@ cogl_fixed_sqrt (CoglFixed x)
+ 	    mask = (mask >> 1 | mask >> 2);
+ 	    bit -= 2;
+ 	}
+-#endif
++//#endif
+ 
+ 	/* now bit indicates the highest bit set; there are two scenarios
+ 	 *
+-- 
+1.7.1
+
only in patch2:
unchanged:
--- clutter-1.0-1.0.8.orig/debian/patches/0002-fix-spelling-errors.patch
+++ clutter-1.0-1.0.8/debian/patches/0002-fix-spelling-errors.patch
@@ -0,0 +1,43 @@
+From c1ec6c8e949cf3d51a0f5f56e81e9e2e183ec786 Mon Sep 17 00:00:00 2001
+From: Heiko Stuebner <heiko@sntech.de>
+Date: Mon, 28 Jun 2010 18:30:33 +0200
+Subject: [PATCH] fix spelling errors
+
+---
+ clutter/clutter-animation.c |    6 +++---
+ 1 files changed, 3 insertions(+), 3 deletions(-)
+
+diff --git a/clutter/clutter-animation.c b/clutter/clutter-animation.c
+index 9ed4368..eacb614 100644
+--- a/clutter/clutter-animation.c
++++ b/clutter/clutter-animation.c
+@@ -1982,7 +1982,7 @@ clutter_actor_animate (ClutterActor *actor,
+  * @n_properties: number of property names and values
+  * @properties: (array length=n_properties) (element-type utf8): a vector
+  *    containing the property names to set
+- * @values: (array length=n_properies): a vector containing the
++ * @values: (array length=n_properties): a vector containing the
+  *    property values to set
+  *
+  * Animates the given list of properties of @actor between the current
+@@ -2034,7 +2034,7 @@ clutter_actor_animatev (ClutterActor        *actor,
+  * @n_properties: number of property names and values
+  * @properties: (array length=n_properties) (element-type utf8): a vector
+  *    containing the property names to set
+- * @values: (array length=n_properies): a vector containing the
++ * @values: (array length=n_properties): a vector containing the
+  *    property values to set
+  *
+  * Animates the given list of properties of @actor between the current
+@@ -2089,7 +2089,7 @@ clutter_actor_animate_with_timelinev (ClutterActor        *actor,
+  * @n_properties: number of property names and values
+  * @properties: (array length=n_properties) (element-type utf8): a vector
+  *    containing the property names to set
+- * @values: (array length=n_properies): a vector containing the
++ * @values: (array length=n_properties): a vector containing the
+  *    property values to set
+  *
+  * Animates the given list of properties of @actor between the current
+-- 
+1.7.1
+
